==> schema_metatag-7.x-1.0.tar.gz: schema_metatag/src/SchemaItemListElementBreadcrumbBase.php <==
<?php

/**
 * All Schema.org Breadcrumb tags should extend this class.
 */
class SchemaItemListElementBreadcrumbBase extends SchemaItemListElementBase {

  /**
   * {@inheritdoc}
   */
  public function getForm(array $options = []) {
    $form['value'] = [
      '#type' => 'select',
      '#title' => $this->label(),
      '#default_value' => $this->value(),
      '#empty_option' => t('No'),
      '#empty_value' => '',
      '#options' => [
        'Yes' => $this->t('Yes'),
      ],
      '#description' => $this->description(),
      '#element_validate' => [[get_class($this), 'validateTag']],
    ];
    // Validation from parent::getForm() got wiped out, so add callback.
    $form['value']['#element_validate'][] = 'schema_metatag_element_validate';
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public static function testValue() {
    return 'Yes';
  }

  /**
   * {@inheritdoc}
   */
  public static function outputValue($input_value) {
    $output_value = parent::outputValue($input_value);
    $items = [];
    if (!empty($output_value)) {
      $items = [
        "@type" => "BreadcrumbList",
        "itemListElement" => $output_value,
      ];
    }
    return $items;
  }

  /**
   * {@inheritdoc}
   */
  public static function getItems($input_value) {
    $values = [];
    if (!empty($input_value)) {
      $entity_route = \Drupal::service('current_route_match')->getCurrentRouteMatch();
      $breadcrumbs = \Drupal::service('breadcrumb')->build($entity_route)->getLinks();
      $key = 1;
      foreach ($breadcrumbs as $item) {
        // Modules that add the current page to the breadcrumb set it to an
        // empty path, so an empty path is the current path.
        $url = $item->getUrl()->setAbsolute()->toString();
        if (empty($url)) {
          $url = Url::fromRoute('<current>')->setAbsolute()->toString();
        }
        $text = $item->getText();
        $text = is_object($text) ? $text->render() : $text;
        $values[$key] = [
          '@id' => $url,
          'name' => $text,
        ];
        $key++;
      }
    }
    return $values;
  }

}

==> schema_metatag-7.x-1.2.tar.gz: schema_metatag/src/SchemaItemListElementBreadcrumbBase.php <==
<?php

/**
 * All Schema.org Breadcrumb tags should extend this class.
 */
class SchemaItemListElementBreadcrumbBase extends SchemaItemListElementBase {

  /**
   * {@inheritdoc}
   */
  public function getForm(array $options = []) {
    $form['value'] = [
      '#type' => 'select',
      '#title' => $this->label(),
      '#default_value' => $this->value(),
      '#empty_option' => t('No'),
      '#empty_value' => '',
      '#options' => [
        'Yes' => $this->t('Yes'),
      ],
      '#description' => $this->description(),
    ];

    // Validation from parent::getForm() got wiped out, so add callback.
    $form['value']['#element_validate'][] = 'schema_metatag_element_validate';

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public static function testValue() {
    return 'Yes';
  }

  /**
   * {@inheritdoc}
   */
  public static function outputValue($input_value) {
    $output_value = parent::outputValue($input_value);
    $items = [];
    if (!empty($output_value)) {
      $items = [
        "@type" => "BreadcrumbList",
        "itemListElement" => $output_value,
      ];
    }
    return $items;
  }

  /**
   * {@inheritdoc}
   */
  public static function getItems($input_value) {
    $values = [];
    if (!empty($input_value)) {
      $breadcrumbs = drupal_get_breadcrumb();

      // Methods on DrupalDefaultMetaTag can't be called statically, and we
      // can't use $this from a static method, so create an empty instance.
      $data = $info = [];
      $processor = new DrupalDefaultMetaTag($data, $info);
      $key = 1;
      foreach ($breadcrumbs as $item) {
        $text = strip_tags($item);
        $url = '';
        $matches = [];
        if (preg_match('/href="([^"]*)"/', $item, $matches)) {
          if (!empty($matches[1])) {
            $url = $matches[1];
            $url = $processor->convertUrlToAbsolute($url);
          }
        }
        $values[$key] = [
          '@id' => $url,
          'name' => $text,
          'url' => $url,
        ];
         $key++;
      }
    }
    return $values;
  }

}
